@@ -26,6 +26,7 @@
 #include "util.h"
 #include "database.h"
 
+#include <QStandardPaths>
 #include <QDebug>
 
 using namespace Baloo;
@@ -33,6 +34,7 @@ using namespace Baloo;
 FileIndexingQueue::FileIndexingQueue(Database* db, QObject* parent)
     : IndexingQueue(parent)
     , m_db(db)
+    , m_testMode(false)
     , m_indexJob(0)
 {
     m_maxSize = 1200;
@@ -55,10 +57,11 @@ void FileIndexingQueue::fillQueue()
         Xapian::Database* db = m_db->xapianDatabase()->db();
         Xapian::Enquire enquire(*db);
         enquire.set_query(Xapian::Query("Z1"));
+        enquire.set_weighting_scheme(Xapian::BoolWeight());
 
         Xapian::MSet mset = enquire.get_mset(0, m_maxSize - m_fileQueue.size());
         Xapian::MSetIterator it = mset.begin();
-        for (; it != mset.end(); it++) {
+        for (; it != mset.end(); ++it) {
             m_fileQueue << *it;
         }
     }
@@ -80,29 +83,32 @@ void FileIndexingQueue::processNextIteration()
     QVector<uint> files;
     files.reserve(m_batchSize);
 
-    for (int i=0; i<m_batchSize && m_fileQueue.size(); i++) {
+    for (int i=0; i<m_batchSize && m_fileQueue.size(); ++i) {
         files << m_fileQueue.pop();
     }
 
     Q_ASSERT(m_indexJob == 0);
     m_indexJob = new FileIndexingJob(files, this);
-    connect(m_indexJob, SIGNAL(indexingFailed(uint)), this, SLOT(slotIndexingFailed(uint)));
-    connect(m_indexJob, SIGNAL(finished(KJob*)), SLOT(slotFinishedIndexingFile(KJob*)));
+    if (m_testMode) {
+        m_indexJob->setCustomDbPath(m_db->path());
+    }
+    connect(m_indexJob, &FileIndexingJob::indexingFailed, this, &FileIndexingQueue::slotIndexingFailed);
+    connect(m_indexJob, &FileIndexingJob::finished, this, &FileIndexingQueue::slotFinishedIndexingFile);
 
     m_indexJob->start();
 }
 
 void FileIndexingQueue::slotFinishedIndexingFile(KJob* job)
 {
+    Q_ASSERT(job == m_indexJob);
+    m_indexJob = 0;
+
     // The process would have modified the db
     m_db->xapianDatabase()->db()->reopen();
     if (m_fileQueue.isEmpty()) {
         fillQueue();
     }
     finishIteration();
-
-    Q_ASSERT(job == m_indexJob);
-    m_indexJob = 0;
 }
 
 void FileIndexingQueue::slotIndexingFailed(uint id)
@@ -114,6 +120,7 @@ void FileIndexingQueue::slotIndexingFailed(uint id)
         updateIndexingLevel(doc, -1);
         Q_EMIT newDocument(id, doc);
     } catch (const Xapian::Error& err) {
+        qDebug() << err.get_description().c_str();
     }
 }
 
